@@ -2,14 +2,18 @@ import requests
 import time
 import signal
 import subprocess
-from queue import Queue
 from multiprocessing import  current_process
 from threading import Thread
 import json
 try:
+    # python 3
     from urllib.parse import urljoin
+    from queue import Queue
 except ImportError:
+    # python 2
     from urlparse import urljoin
+    from Queue import Queue
+
 
 from .variables import task_pidfile
 from .public import write_pid
