@@ -29,8 +29,8 @@ def register(server, label, tag, timeout):
     timestamp = str(round(time.time() * 1000000))
     tags = {}
     for t in tag:
-        key = t.split('=', maxsplit=1)[0]
-        value = t.split('=', maxsplit=1)[1]
+        key = t.strip().split('=', 1)[0]
+        value = t.strip().split('=', 1)[1]
         tags[key] = value
     data = {"sessionId": "", "timestamp": timestamp, "label": label, "tags": tags}
     headers = {"Content-Type": "application/json"}
